@@ -17,7 +17,8 @@ cat > system/install.sh <<'EOF'
 #!/bin/bash
 set -e
 set -u
-apt-get install build-essential perlbrew
+apt-get install -y build-essential perlbrew locales
+localedef -i en_US -f UTF-8 en_US.UTF-8
 export PERLBREW_ROOT=/opt/perlbrew
 mkdir -p $PERLBREW_ROOT
 perlbrew init
@@ -35,4 +36,4 @@ chmod +x system/install.sh
 # This should now install perlbrew, switch to perlbrew to 5.24.1, and install cpanm
 chroot system /install.sh
 
-echo The system is now ready to be used
\ No newline at end of file
+echo The system is now ready to be used
